API Reference
=============

Flatten module
--------------

.. automodule:: spoonbill.flatten
   :members:
   :undoc-members:

CLI module
----------

.. automodule:: spoonbill.cli
   :members:
   :undoc-members:

Spec module
-----------

.. automodule:: spoonbill.spec
   :members:
   :undoc-members:

Stats module
------------

.. automodule:: spoonbill.stats
   :members:
   :undoc-members:

Writer modules
--------------

.. automodule:: spoonbill.writers.base_writer
   :members:
   :undoc-members:
   :special-members: __init__

CSV
~~~

.. automodule:: spoonbill.writers.csv
   :members:
   :undoc-members:

XLSX
~~~~

.. automodule:: spoonbill.writers.xlsx
   :members:
   :undoc-members:
